# Copyright (c) 2020 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Module defining AbstractMeasurer class."""

from abc import ABCMeta, abstractmethod


class AbstractMeasurer(metaclass=ABCMeta):
    """Abstract class defining common API for measurement providers."""

    @abstractmethod
    def measure(self, duration, transmit_rate):
        """Perform trial measurement and return the result.

        :param duration: Trial duration [s].
        :param transmit_rate: Target transmit rate [tps].
        :type duration: float
        :type transmit_rate: float
        :returns: Structure containing the result of the measurement.
        :rtype: ReceiveRateMeasurement.ReceiveRateMeasurement
        """
